Host

Trait Host 

pub trait Host: Send {
    // Required methods
    fn get(
        &mut self,
        name: String,
    ) -> impl Future<Output = Result<String, Error>> + Send;
    fn convert_error(&mut self, err: Error) -> Result<Error>;
}

Required Methods

fn get( &mut self, name: String, ) -> impl Future<Output = Result<String, Error>> + Send

Get an application variable value for the current component.

The name must match one defined in in the component manifest.

fn convert_error(&mut self, err: Error) -> Result<Error>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized + Send> Host for &mut _T

Source

fn get( &mut self, name: String, ) -> impl Future<Output = Result<String, Error>> + Send

Get an application variable value for the current component.

The name must match one defined in in the component manifest.

Source

fn convert_error(&mut self, err: Error) -> Result<Error>

Implementors